/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * dbus-interface.h
 * Copyright (C) Kevin DeKorte 2006 <kdekorte@gmail.com>
 * 
 * dbus-interface.h is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * dbus-interface.h is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dbus-interface.h.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <glib.h>
#ifdef DBUS_ENABLED
#include <dbus/dbus.h>
#include <dbus/dbus-glib-lowlevel.h>
#endif
#include "support.h"
#ifdef XSCRNSAVER_ENABLED
#include <X11/extensions/scrnsaver.h>
#endif

#ifdef DBUS_ENABLED
DBusConnection *connection;
#endif
guint ss_cookie;
guint sm_cookie;
gboolean screensaver_disabled;
gboolean dbus_hookup(gint windowid, gint controlid);
